Using Extensions — Recipe 0.7.2 documentation

# Using Extensions

This part of the documentation services to give you an idea that are otherwise hard to extract from the API Documentation

Extensions build on the core behavior or recipe to let you perform What are extensions for?

## Automatic Filtering

The AutomaticFilter extension

## Summarizing over Dimensions

SummarizeOver

## Merging multiple tables

BlendRecipe

## Adding comparison data

CompareRecipe

## Anonymizing data

Anonymize

# Advanced Features

## Database connections